diff --git a/Gemfile b/Gemfile
index 01af193..dd2900b 100644
--- a/Gemfile
+++ b/Gemfile
@@ -42,10 +42,10 @@ platforms :mri do
     gem "mysql2", "~> 0.2.7"
   end
 
-  group :postgres do
-    gem "pg", "~> 0.9.0"
-    #   gem "postgres-pr"
-  end
+  #group :postgres do
+  #  gem "pg", "~> 0.9.0"
+  #  #   gem "postgres-pr"
+  #end
 end
 
 platforms :mri_18 do
diff --git a/app/models/auth_source_ldap.rb b/app/models/auth_source_ldap.rb
index ea1ed3a..a7df639 100644
--- a/app/models/auth_source_ldap.rb
+++ b/app/models/auth_source_ldap.rb
@@ -11,6 +11,7 @@
 # See doc/COPYRIGHT.rdoc for more details.
 #++
 
+require 'ldap'
 require 'net/ldap'
 require 'iconv'
 
@@ -35,7 +36,7 @@ class AuthSourceLdap < AuthSource
       logger.debug "Authentication successful for '#{login}'" if logger && logger.debug?
       return attrs.except(:dn)
     end
-  rescue  Net::LDAP::LdapError => text
+  rescue  LDAP::Error => text
     raise "LdapError: " + text
   end
 
@@ -43,7 +44,7 @@ class AuthSourceLdap < AuthSource
   def test_connection
     ldap_con = initialize_ldap_con(self.account, self.account_password)
     ldap_con.open { }
-  rescue  Net::LDAP::LdapError => text
+  rescue  LDAP::Error => text
     raise "LdapError: " + text
   end
 
@@ -65,7 +66,12 @@ class AuthSourceLdap < AuthSource
                 :encryption => (self.tls ? :simple_tls : nil)
               }
     options.merge!(:auth => { :method => :simple, :username => ldap_user, :password => ldap_password }) unless ldap_user.blank? && ldap_password.blank?
-    Net::LDAP.new options
+    if self.tls
+      conn = LDAP::SSLConn.new(self.host, self.port, self.tls )
+    else
+      conn = LDAP::Conn.new(self.host, self.port )
+    end
+    conn.set_option(LDAP::LDAP_OPT_PROTOCOL_VERSION, 3)
   end
 
   def get_user_attributes_from_ldap_entry(entry)
@@ -91,20 +97,20 @@ class AuthSourceLdap < AuthSource
   # Check if a DN (user record) authenticates with the password
   def authenticate_dn(dn, password)
     if dn.present? && password.present?
-      initialize_ldap_con(dn, password).bind
+      initialize_ldap_con(dn, password).bind(dn, password)
     end
   end
 
   # Get the user's dn and any attributes for them, given their login
   def get_user_dn(login)
     ldap_con = initialize_ldap_con(self.account, self.account_password)
-    login_filter = Net::LDAP::Filter.eq( self.attr_login, login )
-    object_filter = Net::LDAP::Filter.eq( "objectClass", "*" )
+    filter = self.attr_login + "=" + encode(login)
     attrs = {}
 
-    ldap_con.search( :base => self.base_dn,
-                     :filter => object_filter & login_filter,
-                     :attributes=> search_attributes) do |entry|
+    ldap_con.search( self.base_dn, 
+		     LDAP::LDAP_SCOPE_SUBTREE,
+                     filter,
+                     search_attributes) do |entry|
 
       if onthefly_register?
         attrs = get_user_attributes_from_ldap_entry(entry)
@@ -123,4 +129,12 @@ class AuthSourceLdap < AuthSource
       entry[attr_name].is_a?(Array) ? entry[attr_name].first : entry[attr_name]
     end
   end
+  
+  def encode(value)
+	value = value.gsub("\\", "\\\\5c")
+	value = value.gsub("*", "\\\\2a")
+	value = value.gsub("(", "\\\\28")
+	value = value.gsub(")", "\\\\29")
+	value = value.gsub("\000", "\\\\00")
+  end
 end

